@@ -2,6 +2,7 @@
 Courses application admin
 """
 from itertools import chain
+from operator import itemgetter
 
 from django import forms
 from django.conf import settings
@@ -55,6 +56,7 @@ class CourseRunAdminForm(TranslatableModelForm):
             "languages",
             "enrollment_count",
             "catalog_visibility",
+            "sync_mode",
         ]
 
     def __init__(self, *args, **kwargs):
@@ -109,6 +111,10 @@ class CourseRunAdminForm(TranslatableModelForm):
         if len(course_query) < 2:
             self.fields["direct_course"].widget = forms.HiddenInput()
 
+        self.fields["languages"].choices = sorted(
+            self.fields["languages"].choices, key=itemgetter(1)
+        )
+
     def clean_direct_course(self):
         """Ensure that the user has the required permissions to change the related course page."""
         course = self.cleaned_data["direct_course"]
@@ -142,6 +148,7 @@ class CourseRunAdmin(FrontendEditableAdminMixin, TranslatableAdmin):
         "languages",
         "enrollment_count",
         "catalog_visibility",
+        "sync_mode",
     )
     list_display = ["id"]
     form = CourseRunAdminForm
