@@ -12,6 +12,17 @@ class LMSHandler:
     via the `COURSE_REGEX` configured for each LMS.
     """
 
+    @staticmethod
+    def get_lms_classes():
+        """
+        Return all enabled LMS classes.
+        """
+
+        return {
+            import_string(lms_configuration["BACKEND"])
+            for lms_configuration in settings.RICHIE_LMS_BACKENDS
+        }
+
     @staticmethod
     def select_lms(url):
         """
@@ -24,6 +35,7 @@ class LMSHandler:
         if url is None:
             return None
 
+        # First check if it matches a configured LMS
         for lms_configuration in settings.RICHIE_LMS_BACKENDS:
             if re.match(lms_configuration.get("COURSE_REGEX", r".*"), url):
                 return import_string(lms_configuration["BACKEND"])(lms_configuration)
