@@ -4,6 +4,7 @@ Base backend to connect richie with an LMS
 from django.conf import settings
 
 from ..models.course import CourseRunSyncMode
+from ..serializers import SyncCourseRunSerializer
 
 
 class BaseLMSBackend:
@@ -16,6 +17,18 @@ class BaseLMSBackend:
         super().__init__(*args, **kwargs)
         self.configuration = configuration
 
+    def clean_course_run_data(self, data):
+        """
+        Clean course run data. By default, it does nothing, but it aims to be overridden
+        by child class if there is a need to transform data payload before using it.
+        """
+        return data
+
+    @staticmethod
+    def get_course_run_serializer(data, partial=False):
+        """Prepare data and return a bound serializer."""
+        return SyncCourseRunSerializer(data=data, partial=partial)
+
     @property
     def default_course_run_sync_mode(self):
         """Course run synchronization mode."""
