@@ -114,7 +114,7 @@ def regenerate_indices(logger):
     def perform_aliases_update():
         try:
             ES_INDICES_CLIENT.update_aliases(
-                dict(actions=actions_to_create_aliases + actions_to_delete_aliases)
+                {"actions": actions_to_create_aliases + actions_to_delete_aliases}
             )
         except RequestError as exception:
             # This operation can fail if an index exists with the same name as an alias we're
