@@ -23,12 +23,13 @@ from ...courses.models import (
     Course,
     CourseRunCatalogVisibility,
     CourseState,
+    Licence,
 )
 from ..defaults import ES_INDICES_PREFIX, ES_STATE_WEIGHTS
 from ..forms import CourseSearchForm
 from ..text_indexing import MULTILINGUAL_TEXT
 from ..utils.i18n import get_best_field_language
-from ..utils.indexers import slice_string_for_completion
+from ..utils.indexers import get_course_pace, slice_string_for_completion
 
 BEST_STATE_SCRIPT = """
     DateTimeFormatter formatter = DateTimeFormatter.ofPattern(
@@ -184,6 +185,7 @@ class CoursesIndexer:
             },
             # Keywords
             "categories": {"type": "keyword"},
+            "licences": {"type": "keyword"},
             "organizations": {"type": "keyword"},
             "persons": {"type": "keyword"},
             # Searchable
@@ -213,6 +215,7 @@ class CoursesIndexer:
                 "type": "object",
                 "enabled": False,
             },
+            "pace": {"type": "integer"},  # Expresses minutes per week
         },
     }
     display_fields = [
@@ -603,6 +606,16 @@ class CoursesIndexer:
             .values("start", "end", "enrollment_start", "enrollment_end", "languages")
         ]
 
+        licences = (
+            Licence.objects.filter(
+                licencepluginmodel__cmsplugin_ptr__placeholder__page__course=course,
+                licencepluginmodel__cmsplugin_ptr__placeholder__slot="course_license_content",
+            )
+            .distinct()
+            .order_by("id")
+            .values_list("id", flat=True)
+        )
+
         return {
             "_id": course.get_es_id(),
             "_index": index,
@@ -644,6 +657,7 @@ class CoursesIndexer:
             "is_new": len(course_runs) == 1,
             # If titles is an empty dict, it means the course is not published in any language:
             "is_listed": bool(course.is_listed and titles),
+            "licences": list(licences),
             # Pick the highlighted organization from the organizations QuerySet to benefit from
             # the prefetch of related title sets
             "organization_highlighted": {
@@ -686,6 +700,9 @@ class CoursesIndexer:
                 ],
                 {},
             ),
+            "pace": None
+            if course.is_self_paced
+            else get_course_pace(course.effort, course.duration),
             "title": titles,
         }
 
